package Source::Repository::Mass::Transform::Embedded;

use strict;
use warnings;
use Source::Repository::Mass::Transform;
use RPM::Source::Transform 0.016;
use RPM::Source::Transformation::RPMEditorProvider;
use RPM::Source::Transformation::PkgWriter;

our @ISA = qw(Source::Repository::Mass::Transform);
our $embedded_class='RPM::Source::Transform';

$RPM::Source::Transformation::PkgWriter::outputdir=$Source::Repository::Mass::Transform::DEFAULT_OUTDIR;

our $verbose=1;

sub new {
    my $class = shift;
    my $self = $class->SUPER::new(@_);
    $RPM::Source::Transform::verbose=$Source::Repository::Mass::verbose;
    $self->{-transform}=$embedded_class->new(-embedded=>1);
    return $self;
};

sub get_longopt {
    my $class = shift;
    return $class->SUPER::get_longopt(@_), $embedded_class->get_longopt;
}

sub process_options {
    my $self = shift;
    $self->SUPER::process_options(@_);
    $embedded_class->process_options;
}

sub process_pair {
    my ($self,$pkgpair,$transaction_name,$transaction_count)=@_;
    my ($originname, $destname)=($pkgpair->originname,$pkgpair->destname);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    if (not $origin) {
	print STDERR "ERROR: origin file for $originname not found.\n";
	return;
    }
    my $converter=$self->{-transform};
    my $converter_opt=$converter->mk_opt();
    $converter_opt->{-rename}=$destname if $destname ne $originname and not $Source::Repository::Mass::Transform::suppress_rename;

    $converter_opt->{-transaction_output_subdir} = &Source::Repository::Mass::Transform::__transaction_output_subdir($transaction_name,$transaction_count) if defined($transaction_name);

    my ($spec,$parent)=$self->get_spec_parent($pkgpair,$converter,$converter_opt);

    if ($Source::Repository::Mass::verbose) {
	print STDERR "info: origin: $spec->{SOURCERPM}\n" if ($spec and $spec->{SOURCERPM});
	print STDERR "info: parent: $parent->{SOURCERPM}\n" if $parent and $parent->{SOURCERPM};
    }

    #$self->process_pair_hook($pkgpair, $converter_opt, $spec, $parent);
    $converter->transform_once($spec,$parent,$converter_opt);

    print STDERR "---*---\n" if $verbose;
}

sub get_spec_parent {
    my ($self,$pkgpair,$converter,$converter_opt)=@_;
    my ($spec,$parent);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    $spec=$RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2spec(
	    $self->{-originrepo}->pkg4rpmeditor($origin)
	) if $origin;
    $parent=$RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2parent(
	$dest ? $self->{-destrepo}->pkg4rpmeditor($dest): undef
	);
    return ($spec,$parent);
}

1;
